@@ -6,6 +6,8 @@
 #include <QScreen>
 #include <algorithm>
 
+#include <private/qwaylandscreen_p.h>
+
 // Function to erase a window from the vector
 void eraseWindow(std::vector<WId>& windows, WId tgt) {
     // Use std::vector::iterator to find the window
@@ -270,10 +272,19 @@ void LXQtTaskbarWlrootsBackend::moveApplicationToPrevNextMonitor(WId, bool, bool
 {
 }
 
-bool LXQtTaskbarWlrootsBackend::isWindowOnScreen(QScreen *, WId) const
+bool LXQtTaskbarWlrootsBackend::isWindowOnScreen(QScreen *screen, WId windowId) const
 {
-    // TODO: Manage based on output-enter/output-leave
-    return true;
+    LXQtTaskbarWlrootsWindow *window = getWindow(windowId);
+    if(window)
+    {
+        QtWaylandClient::QWaylandScreen *waylandScreen = dynamic_cast<QtWaylandClient::QWaylandScreen*>(screen->handle());
+        if (waylandScreen)
+        {
+            wl_output *output = waylandScreen->output();
+            return window->windowState.outputs.contains(output);
+        }
+    }
+    return false;
 }
 
 bool LXQtTaskbarWlrootsBackend::setDesktopLayout(Qt::Orientation, int, int, bool) {
@@ -449,6 +460,7 @@ void LXQtTaskbarWlrootsBackend::addToWindows(WId winId)
     connect(window, &LXQtTaskbarWlrootsWindow::fullscreenChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
     connect(window, &LXQtTaskbarWlrootsWindow::maximizedChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
     connect(window, &LXQtTaskbarWlrootsWindow::minimizedChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
+    connect(window, &LXQtTaskbarWlrootsWindow::outputsChanged, this, &LXQtTaskbarWlrootsBackend::onOutputsChanged);
 
     emit windowAdded( winId );
     emit windowPropertyChanged(winId, int(LXQtTaskBarWindowProperty::WindowClass));
@@ -469,6 +481,7 @@ void LXQtTaskbarWlrootsBackend::removeWindow()
         disconnect(window, &LXQtTaskbarWlrootsWindow::fullscreenChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
         disconnect(window, &LXQtTaskbarWlrootsWindow::maximizedChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
         disconnect(window, &LXQtTaskbarWlrootsWindow::minimizedChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
+        disconnect(window, &LXQtTaskbarWlrootsWindow::outputsChanged, this, &LXQtTaskbarWlrootsBackend::onOutputsChanged);
 
         WId winId = window->getWindowId();
         eraseWindow(windows, winId);
@@ -576,6 +589,7 @@ void LXQtTaskbarWlrootsBackend::onParentChanged()
             disconnect(window, &LXQtTaskbarWlrootsWindow::fullscreenChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
             disconnect(window, &LXQtTaskbarWlrootsWindow::maximizedChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
             disconnect(window, &LXQtTaskbarWlrootsWindow::minimizedChanged, this, &LXQtTaskbarWlrootsBackend::onStateChanged);
+            disconnect(window, &LXQtTaskbarWlrootsWindow::outputsChanged, this, &LXQtTaskbarWlrootsBackend::onOutputsChanged);
             eraseWindow(windows, window->getWindowId());
             lastActivated.remove(window->getWindowId());
             // announce that it's removed
@@ -615,6 +629,12 @@ void LXQtTaskbarWlrootsBackend::onStateChanged()
         emit windowPropertyChanged(window->getWindowId(), int(LXQtTaskBarWindowProperty::State));
 }
 
+void LXQtTaskbarWlrootsBackend::onOutputsChanged()
+{
+    if (auto window = qobject_cast<LXQtTaskbarWlrootsWindow *>(QObject::sender()))
+        emit windowPropertyChanged(window->getWindowId(), int(LXQtTaskBarWindowProperty::Geometry));
+}
+
 bool LXQtTaskbarWlrootsBackend::acceptWindow(WId window) const
 {
     if(transients.contains(window))
@@ -661,38 +681,26 @@ void LXQtTaskbarWlrootsBackend::setLastActivated(WId id)
 
 int LXQtWMBackendWlrootsLibrary::getBackendScore(const QString& key) const
 {
-	if (key == QStringLiteral("wlroots"))
-	{
-		return 50;
-	}
+    if (key.compare(QStringLiteral("wlroots"), Qt::CaseInsensitive) == 0)
+    {
+        return 50;
+    }
 
-	else if (key == QStringLiteral("wayfire"))
-	{
-		return 30;
-	}
+    static const QStringList supportedList = {QStringLiteral("labwc"),
+                                              QStringLiteral("sway"),
+                                              QStringLiteral("wayfire"),
+                                              // The following compositors are also supported,
+                                              // although they are not based on wlroots.
+                                              QStringLiteral("hyprland"),
+                                              QStringLiteral("river"),
+                                              QStringLiteral("niri")};
+    if (supportedList.contains(key, Qt::CaseInsensitive))
+    {
+        return 30;
+    }
 
-	else if (key == QStringLiteral("sway"))
-	{
-		return 30;
-	}
-
-	else if (key == QStringLiteral("hyprland"))
-	{
-		return 30;
-	}
-
-	else if (key == QStringLiteral("labwc"))
-	{
-		return 30;
-	}
-
-	else if (key == QStringLiteral("river"))
-	{
-		return 30;
-	}
-
-	// Unsupported
-	return 0;
+    // Unsupported
+    return 0;
 }
 
 
