@@ -357,7 +357,7 @@ bool LXQtWMBackendX11::setWindowLayer(WId windowId, LXQtTaskBarWindowLayer layer
 
 LXQtTaskBarWindowState LXQtWMBackendX11::getWindowState(WId windowId) const
 {
-    KWindowInfo info(windowId,NET::WMState | NET::XAWMState);
+    KWindowInfo info(windowId, NET::WMState | NET::XAWMState);
     if(info.isMinimized())
         return LXQtTaskBarWindowState::Minimized;
 
@@ -554,6 +554,11 @@ void LXQtWMBackendX11::moveApplicationToPrevNextMonitor(WId windowId, bool next,
     }
 }
 
+int LXQtWMBackendX11::onAllWorkspacesEnum() const
+{
+    return NET::OnAllDesktops;
+}
+
 bool LXQtWMBackendX11::isWindowOnScreen(QScreen *screen, WId windowId) const
 {
     //TODO: old code was:
