@@ -53,6 +53,8 @@
 #include <KX11Extras>
 #include <NETWM>
 
+#include <algorithm>
+
 #include "backends/ilxqtabstractwmiface.h"
 
 
@@ -139,6 +141,7 @@ LXQtPanel::LXQtPanel(const QString &configGroup, LXQt::Settings *settings, QWidg
     mPosition(ILXQtPanel::PositionBottom),
     mScreenNum(0), //whatever (avoid conditional on uninitialized value)
     mActualScreenNum(0),
+    mWaylandScreenNum(-1), // not set yet (on Wayland)
     mHidable(false),
     mVisibleMargin(true),
     mHideOnOverlap(false),
@@ -215,8 +218,11 @@ LXQtPanel::LXQtPanel(const QString &configGroup, LXQt::Settings *settings, QWidg
     connect(qApp, &QApplication::screenRemoved, this, [this] (QScreen* oldScreen) {
         disconnect(oldScreen, &QScreen::virtualGeometryChanged, this, &LXQtPanel::ensureVisible);
         disconnect(oldScreen, &QScreen::geometryChanged, this, &LXQtPanel::ensureVisible);
-        // wait until the screen is really removed because it may contain the panel
-        QTimer::singleShot(0, this, &LXQtPanel::ensureVisible);
+        if (QGuiApplication::platformName() != QStringLiteral("wayland"))
+        {
+            // wait until the screen is really removed because it may contain the panel
+            QTimer::singleShot(0, this, &LXQtPanel::ensureVisible);
+        }
     });
     const auto screens = QApplication::screens();
     for(const auto& screen : screens)
@@ -370,22 +376,51 @@ void LXQtPanel::readSettings()
               mSettings->value(QStringLiteral(CFG_KEY_PERCENT), true).toBool(),
               false);
 
-    mScreenNum = mSettings->value(QStringLiteral(CFG_KEY_SCREENNUM), 0).toInt();
-    setPosition(mScreenNum,
-                strToPosition(mSettings->value(QStringLiteral(CFG_KEY_POSITION)).toString(), PositionBottom),
-                false);
+    const auto screens = QApplication::screens();
+    mScreenNum = std::clamp<int>(mSettings->value(QStringLiteral(CFG_KEY_SCREENNUM), 0).toInt(), 0, screens.size() - 1);
+    if (QGuiApplication::platformName() == QStringLiteral("wayland"))
+    {
+        // On Wayland, first check the screen name, and if it does not exist, add it.
+        mScreenName = mSettings->value(QStringLiteral(CFG_KEY_SCREENNAME)).toString();
+        mWaylandScreenNum = mScreenNum;
+        if (mScreenName.isEmpty())
+        {
+            mScreenName = screens.at(mWaylandScreenNum)->name();
+            QTimer::singleShot(0, this, [this] { saveSettings(true); }); // save the found name
+        }
+        else
+        {
+            for (int i = 0; i < screens.size(); ++i)
+            {
+                if (screens.at(i)->name() == mScreenName)
+                {
+                    mWaylandScreenNum = i;
+                    break;
+                }
+            }
+        }
+        setPosition(mWaylandScreenNum,
+                    strToPosition(mSettings->value(QStringLiteral(CFG_KEY_POSITION)).toString(), PositionBottom),
+                    false);
+    }
+    else
+    {
+        setPosition(mScreenNum,
+                    strToPosition(mSettings->value(QStringLiteral(CFG_KEY_POSITION)).toString(), PositionBottom),
+                    false);
+    }
 
     setAlignment(Alignment(mSettings->value(QStringLiteral(CFG_KEY_ALIGNMENT), mAlignment).toInt()), false);
 
     QColor color = mSettings->value(QStringLiteral(CFG_KEY_FONTCOLOR), QString()).value<QColor>();
     if (color.isValid())
-        setFontColor(color, true);
+        setFontColor(color, false);
 
-    setOpacity(mSettings->value(QStringLiteral(CFG_KEY_OPACITY), 100).toInt(), true);
+    setOpacity(mSettings->value(QStringLiteral(CFG_KEY_OPACITY), 100).toInt(), false);
     mReserveSpace = mSettings->value(QStringLiteral(CFG_KEY_RESERVESPACE), true).toBool();
     color = mSettings->value(QStringLiteral(CFG_KEY_BACKGROUNDCOLOR), QString()).value<QColor>();
     if (color.isValid())
-        setBackgroundColor(color, true);
+        setBackgroundColor(color, false);
 
     QString image = mSettings->value(QStringLiteral(CFG_KEY_BACKGROUNDIMAGE), QString()).toString();
     if (!image.isEmpty())
@@ -422,6 +457,16 @@ void LXQtPanel::saveSettings(bool later)
     mSettings->setValue(QStringLiteral(CFG_KEY_PERCENT), mLengthInPercents);
 
     mSettings->setValue(QStringLiteral(CFG_KEY_SCREENNUM), mScreenNum);
+    if (mWaylandScreenNum >= 0) // on Wayland
+    {
+        if (mScreenName.isEmpty())
+        {
+            const auto screens = QApplication::screens();
+            if (mWaylandScreenNum < screens.size())
+                mScreenName = screens.at(mWaylandScreenNum)->name();
+        }
+        mSettings->setValue(QStringLiteral(CFG_KEY_SCREENNAME), mScreenName);
+    }
     mSettings->setValue(QStringLiteral(CFG_KEY_POSITION), positionToStr(mPosition));
 
     mSettings->setValue(QStringLiteral(CFG_KEY_ALIGNMENT), mAlignment);
@@ -449,10 +494,33 @@ void LXQtPanel::saveSettings(bool later)
  ************************************************/
 void LXQtPanel::ensureVisible()
 {
-    if (!canPlacedOn(mScreenNum, mPosition))
-        setPosition(findAvailableScreen(mPosition), mPosition, false);
+    if (!mScreenName.isEmpty() && QGuiApplication::platformName() == QStringLiteral("wayland"))
+    {
+        // Find the Wayland screen number based on the screen name.
+        mWaylandScreenNum = -1; // first unset it
+        const auto screens = QApplication::screens();
+        for (int i = 0; i < screens.size(); ++i)
+        {
+            if (screens.at(i)->name() == mScreenName)
+            {
+                mWaylandScreenNum = i;
+                break;
+            }
+        }
+        if (mWaylandScreenNum < 0)
+            return;
+        if (!canPlacedOn(mWaylandScreenNum, mPosition))
+            setPosition(findAvailableScreen(mPosition), mPosition, false);
+        else
+            mActualScreenNum = mWaylandScreenNum;
+    }
     else
-        mActualScreenNum = mScreenNum;
+    {
+        if (!canPlacedOn(mScreenNum, mPosition))
+            setPosition(findAvailableScreen(mPosition), mPosition, false);
+        else
+            mActualScreenNum = mScreenNum;
+    }
 
     // the screen size might be changed
     realign();
@@ -528,7 +596,7 @@ void LXQtPanel::loadPlugins()
  ************************************************/
 int LXQtPanel::getReserveDimension()
 {
-    return mHidable ? PANEL_HIDE_SIZE : qMax(PANEL_MINIMUM_SIZE, mPanelSize);
+    return mHidable ? PANEL_HIDE_SIZE : std::max(PANEL_MINIMUM_SIZE, mPanelSize);
 }
 
 QMargins LXQtPanel::layerWindowMargins()
@@ -536,7 +604,7 @@ QMargins LXQtPanel::layerWindowMargins()
     QMargins margins;
     if (!mHidden)
         return margins;
-    int offset = PANEL_HIDE_SIZE - qMax(PANEL_MINIMUM_SIZE, mPanelSize); // negative
+    int offset = PANEL_HIDE_SIZE - std::max(PANEL_MINIMUM_SIZE, mPanelSize); // negative
     if (isHorizontal())
     {
         if (mPosition == ILXQtPanel::PositionTop)
@@ -567,7 +635,7 @@ void LXQtPanel::setPanelGeometry(bool animate)
     if (isHorizontal())
     {
         // Horiz panel ***************************
-        rect.setHeight(qMax(PANEL_MINIMUM_SIZE, mPanelSize));
+        rect.setHeight(std::max(PANEL_MINIMUM_SIZE, mPanelSize));
         if (mLengthInPercents)
             rect.setWidth(currentScreen.width() * mLength / 100.0);
         else
@@ -578,7 +646,7 @@ void LXQtPanel::setPanelGeometry(bool animate)
                 rect.setWidth(mLength);
         }
 
-        rect.setWidth(qMax(rect.size().width(), mLayout->minimumSize().width()));
+        rect.setWidth(std::max(rect.size().width(), mLayout->minimumSize().width()));
 
         // Horiz ......................
         switch (mAlignment)
@@ -628,7 +696,7 @@ void LXQtPanel::setPanelGeometry(bool animate)
     else
     {
         // Vert panel ***************************
-        rect.setWidth(qMax(PANEL_MINIMUM_SIZE, mPanelSize));
+        rect.setWidth(std::max(PANEL_MINIMUM_SIZE, mPanelSize));
         if (mLengthInPercents)
             rect.setHeight(currentScreen.height() * mLength / 100.0);
         else
@@ -639,7 +707,7 @@ void LXQtPanel::setPanelGeometry(bool animate)
                 rect.setHeight(mLength);
         }
 
-        rect.setHeight(qMax(rect.size().height(), mLayout->minimumSize().height()));
+        rect.setHeight(std::max(rect.size().height(), mLayout->minimumSize().height()));
 
         // Vert .......................
         switch (mAlignment)
@@ -1012,7 +1080,8 @@ bool LXQtPanel::canPlacedOn(int screenNum, LXQtPanel::Position position)
  ************************************************/
 int LXQtPanel::findAvailableScreen(LXQtPanel::Position position)
 {
-    int current = mScreenNum;
+    int current = (mWaylandScreenNum >= 0 ? mWaylandScreenNum // on Wayland
+                                          : mScreenNum);
 
     for (int i = current; i < QApplication::screens().size(); ++i)
         if (canPlacedOn(i, position))
@@ -1181,8 +1250,9 @@ void LXQtPanel::setLength(int length, bool inPercents, bool save)
  ************************************************/
 void LXQtPanel::setPosition(int screen, ILXQtPanel::Position position, bool save)
 {
-    if (mScreenNum == screen &&
-            mPosition == position)
+    if ((mWaylandScreenNum >= 0 ? mWaylandScreenNum // on Wayland
+                                : mScreenNum) == screen
+        && mPosition == position)
         return;
 
     mActualScreenNum = screen;
@@ -1191,7 +1261,13 @@ void LXQtPanel::setPosition(int screen, ILXQtPanel::Position position, bool save
 
     if (save)
     {
-        mScreenNum = screen;
+        if (mWaylandScreenNum >= 0)
+        {
+            mWaylandScreenNum = screen;
+            mScreenName = qApp->screens().at(screen)->name();
+        }
+        else
+            mScreenNum = screen;
         saveSettings(true);
     }
 
@@ -1287,7 +1363,7 @@ void LXQtPanel::setBackgroundImage(QString path, bool save)
  ************************************************/
 void LXQtPanel::setOpacity(int opacity, bool save)
 {
-    mOpacity = opacity;
+    mOpacity = std::clamp(opacity, 0, 100);
     updateStyleSheet();
 
     if (save)
