@@ -215,39 +215,39 @@ namespace
     typedef std::unique_ptr<ILXQtPanelPluginLibrary> plugin_ptr_t;
     typedef std::tuple<QString, plugin_ptr_t, void *> plugin_tuple_t;
 
-    //NOTE: Please keep the plugins sorted by name while adding new plugins.
-    //NOTE2: we need to reference some (dummy) symbol from (autogenerated) LXQtPluginTranslationLoader.cpp
+    // NOTE: Please keep the plugins sorted by name while adding new plugins.
+    // NOTE2: we need to reference some (dummy) symbol from (autogenerated) LXQtPluginTranslationLoader.cpp
     // to be not stripped (as unused/unreferenced) in static linking time
     static plugin_tuple_t const static_plugins[] = {
 #if defined(WITH_DESKTOPSWITCH_PLUGIN)
-        std::make_tuple(QLatin1String("desktopswitch"), plugin_ptr_t{new DesktopSwitchPluginLibrary}, loadPluginTranslation_desktopswitch_helper),// desktopswitch
+        std::make_tuple(QLatin1String("desktopswitch"), plugin_ptr_t{new DesktopSwitchPluginLibrary}, loadPluginTranslation_desktopswitch_helper), // desktopswitch
 #endif
 #if defined(WITH_FANCYMENU_PLUGIN)
-        std::make_tuple(QLatin1String("fancymenu"), plugin_ptr_t{new LXQtFancyMenuPluginLibrary}, loadPluginTranslation_fancymenu_helper),// fancymenu
+        std::make_tuple(QLatin1String("fancymenu"), plugin_ptr_t{new LXQtFancyMenuPluginLibrary}, loadPluginTranslation_fancymenu_helper), // fancymenu
 #endif
 #if defined(WITH_MAINMENU_PLUGIN)
-        std::make_tuple(QLatin1String("mainmenu"), plugin_ptr_t{new LXQtMainMenuPluginLibrary}, loadPluginTranslation_mainmenu_helper),// mainmenu
+        std::make_tuple(QLatin1String("mainmenu"), plugin_ptr_t{new LXQtMainMenuPluginLibrary}, loadPluginTranslation_mainmenu_helper), // mainmenu
 #endif
 #if defined(WITH_QUICKLAUNCH_PLUGIN)
-        std::make_tuple(QLatin1String("quicklaunch"), plugin_ptr_t{new LXQtQuickLaunchPluginLibrary}, loadPluginTranslation_quicklaunch_helper),// quicklaunch
+        std::make_tuple(QLatin1String("quicklaunch"), plugin_ptr_t{new LXQtQuickLaunchPluginLibrary}, loadPluginTranslation_quicklaunch_helper), // quicklaunch
 #endif
 #if defined(WITH_SHOWDESKTOP_PLUGIN)
-        std::make_tuple(QLatin1String("showdesktop"), plugin_ptr_t{new ShowDesktopLibrary}, loadPluginTranslation_showdesktop_helper),// showdesktop
+        std::make_tuple(QLatin1String("showdesktop"), plugin_ptr_t{new ShowDesktopLibrary}, loadPluginTranslation_showdesktop_helper), // showdesktop
 #endif
 #if defined(WITH_SPACER_PLUGIN)
-        std::make_tuple(QLatin1String("spacer"), plugin_ptr_t{new SpacerPluginLibrary}, loadPluginTranslation_spacer_helper),// spacer
+        std::make_tuple(QLatin1String("spacer"), plugin_ptr_t{new SpacerPluginLibrary}, loadPluginTranslation_spacer_helper), // spacer
 #endif
 #if defined(WITH_STATUSNOTIFIER_PLUGIN)
-        std::make_tuple(QLatin1String("statusnotifier"), plugin_ptr_t{new StatusNotifierLibrary}, loadPluginTranslation_statusnotifier_helper),// statusnotifier
+        std::make_tuple(QLatin1String("statusnotifier"), plugin_ptr_t{new StatusNotifierLibrary}, loadPluginTranslation_statusnotifier_helper), // statusnotifier
 #endif
 #if defined(WITH_TASKBAR_PLUGIN)
-        std::make_tuple(QLatin1String("taskbar"), plugin_ptr_t{new LXQtTaskBarPluginLibrary}, loadPluginTranslation_taskbar_helper),// taskbar
+        std::make_tuple(QLatin1String("taskbar"), plugin_ptr_t{new LXQtTaskBarPluginLibrary}, loadPluginTranslation_taskbar_helper), // taskbar
 #endif
 #if defined(WITH_TRAY_PLUGIN)
-        std::make_tuple(QLatin1String("tray"), plugin_ptr_t{new LXQtTrayPluginLibrary}, loadPluginTranslation_tray_helper),// tray
+        std::make_tuple(QLatin1String("tray"), plugin_ptr_t{new LXQtTrayPluginLibrary}, loadPluginTranslation_tray_helper), // tray
 #endif
 #if defined(WITH_WORLDCLOCK_PLUGIN)
-        std::make_tuple(QLatin1String("worldclock"), plugin_ptr_t{new LXQtWorldClockLibrary}, loadPluginTranslation_worldclock_helper),// worldclock
+        std::make_tuple(QLatin1String("worldclock"), plugin_ptr_t{new LXQtWorldClockLibrary}, loadPluginTranslation_worldclock_helper), // worldclock
 #endif
     };
     static constexpr plugin_tuple_t const * const plugins_begin = static_plugins;
@@ -370,10 +370,20 @@ void Plugin::settingsChanged()
  ************************************************/
 void Plugin::saveSettings()
 {
-    mSettings->setValue(QStringLiteral("alignment"), (mAlignment == AlignLeft) ? QStringLiteral("Left") : QStringLiteral("Right"));
-    mSettings->setValue(QStringLiteral("type"), mDesktopFile.id());
-    mSettings->sync();
-
+    bool syncSettings = false;
+    const QString alignment(mAlignment == AlignLeft ? QStringLiteral("Left") : QStringLiteral("Right"));
+    if (mSettings->value(QStringLiteral("alignment")).toString() != alignment)
+    {
+        mSettings->setValue(QStringLiteral("alignment"), alignment);
+        syncSettings = true;
+    }
+    if (mSettings->value(QStringLiteral("type")).toString() != mDesktopFile.id())
+    {
+        mSettings->setValue(QStringLiteral("type"), mDesktopFile.id());
+        syncSettings = true;
+    }
+    if (syncSettings)
+        mSettings->sync();
 }
 
 
