@@ -34,7 +34,7 @@
     <message>
         <location filename="../config/configpaneldialog.cpp" line="31"/>
         <source>Configure Panel</source>
-        <translation>Configurar painel</translation>
+        <translation>Configurar Painel</translation>
     </message>
     <message>
         <location filename="../config/configpaneldialog.cpp" line="39"/>
@@ -57,7 +57,7 @@
     <message>
         <location filename="../config/configplacement.ui" line="20"/>
         <source>Configure Placement</source>
-        <translation>Configurar posicionamento</translation>
+        <translation>Configurar Posicionamento</translation>
     </message>
     <message>
         <location filename="../config/configplacement.ui" line="44"/>
@@ -148,7 +148,7 @@
         <location filename="../config/configplacement.ui" line="262"/>
         <location filename="../config/configplacement.ui" line="285"/>
         <source>Zero means no animation</source>
-        <translation>Zero desativa animação</translation>
+        <translation>Zero desativa animações</translation>
     </message>
     <message>
         <location filename="../config/configplacement.ui" line="265"/>
@@ -194,43 +194,43 @@
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="154"/>
-        <source>Top of desktop</source>
-        <translation>Topo da área de trabalho</translation>
+        <source>Top of screen</source>
+        <translation>Topo da tela</translation>
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="155"/>
-        <source>Left of desktop</source>
-        <translation>Esquerda da área de trabalho</translation>
+        <source>Left of screen</source>
+        <translation>Esquerda da tela</translation>
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="156"/>
-        <source>Right of desktop</source>
-        <translation>Direita da área de trabalho</translation>
+        <source>Right of screen</source>
+        <translation>Direita da tela</translation>
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="157"/>
-        <source>Bottom of desktop</source>
-        <translation>Abaixo da área de trabalho</translation>
+        <source>Bottom of screen</source>
+        <translation>Fundo da tela</translation>
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="166"/>
-        <source>Top of desktop %1</source>
-        <translation>Topo da área de trabalho %1</translation>
+        <source>Top of screen %1</source>
+        <translation>Topo da tela %1</translation>
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="167"/>
-        <source>Left of desktop %1</source>
-        <translation>Esquerda da área de trabalho %1</translation>
+        <source>Left of screen %1</source>
+        <translation>Esquerda da tela %1</translation>
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="168"/>
-        <source>Right of desktop %1</source>
-        <translation>Direita da área de trabalho %1</translation>
+        <source>Right of screen %1</source>
+        <translation>Direita da tela %1</translation>
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="169"/>
-        <source>Bottom of desktop %1</source>
-        <translation>Abaixo da área de trabalho %1</translation>
+        <source>Bottom of screen %1</source>
+        <translation>Fundo da tela %1</translation>
     </message>
     <message>
         <location filename="../config/configplacement.cpp" line="194"/>
@@ -240,7 +240,7 @@
     <message>
         <location filename="../config/configplacement.cpp" line="196"/>
         <source>Bottom</source>
-        <translation>Base</translation>
+        <translation>Fundo</translation>
     </message>
 </context>
 <context>
@@ -248,17 +248,17 @@
     <message>
         <location filename="../config/configpluginswidget.ui" line="14"/>
         <source>Configure Plugins</source>
-        <translation>Configurar plugins</translation>
+        <translation>Configurar Plugins</translation>
     </message>
     <message>
         <location filename="../config/configpluginswidget.ui" line="84"/>
         <source>Note: changes made in this page cannot be reset.</source>
-        <translation>Nota: quaisquer mudanças feitas nesta página, não poderão ser restauradas.</translation>
+        <translation>Nota: mudanças feitas nesta página não poderão ser restauradas.</translation>
     </message>
     <message>
         <location filename="../config/configpluginswidget.ui" line="112"/>
         <source>Move up</source>
-        <translation>Mover acima</translation>
+        <translation>Mover para cima</translation>
     </message>
     <message>
         <location filename="../config/configpluginswidget.ui" line="115"/>
@@ -272,7 +272,7 @@
     <message>
         <location filename="../config/configpluginswidget.ui" line="126"/>
         <source>Move down</source>
-        <translation>Mover abaixo</translation>
+        <translation>Mover para baixo</translation>
     </message>
     <message>
         <location filename="../config/configpluginswidget.ui" line="147"/>
@@ -376,45 +376,45 @@ Colorir ícones baseado no estilo widget (paleta)</translation>
 <context>
     <name>LXQtPanel</name>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1419"/>
-        <location filename="../lxqtpanel.cpp" line="1445"/>
+        <location filename="../lxqtpanel.cpp" line="1495"/>
+        <location filename="../lxqtpanel.cpp" line="1521"/>
         <source>Panel</source>
         <translation>Painel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1448"/>
+        <location filename="../lxqtpanel.cpp" line="1524"/>
         <source>Configure Panel</source>
         <translation>Configurar painel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1453"/>
+        <location filename="../lxqtpanel.cpp" line="1529"/>
         <source>Manage Widgets</source>
         <translation>Gerenciar widgets</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1459"/>
+        <location filename="../lxqtpanel.cpp" line="1535"/>
         <source>Add New Panel</source>
         <translation>Adicionar novo painel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1466"/>
+        <location filename="../lxqtpanel.cpp" line="1542"/>
         <source>Remove Panel</source>
         <comment>Menu Item</comment>
         <translation>Remover painel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1471"/>
+        <location filename="../lxqtpanel.cpp" line="1547"/>
         <source>Lock This Panel</source>
         <translation>Travar painel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1634"/>
+        <location filename="../lxqtpanel.cpp" line="1710"/>
         <source>Remove Panel</source>
         <comment>Dialog Title</comment>
         <translation>Remover painel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1635"/>
+        <location filename="../lxqtpanel.cpp" line="1711"/>
         <source>Removing a panel can not be undone.
 Do you want to remove this panel?</source>
         <translation>A remoção de um painel não pode ser desfeita.
@@ -424,17 +424,17 @@ Deseja mesmo remover este painel?</translation>
 <context>
     <name>Plugin</name>
     <message>
-        <location filename="../plugin.cpp" line="445"/>
+        <location filename="../plugin.cpp" line="455"/>
         <source>Configure &quot;%1&quot;</source>
         <translation>Configurar &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../plugin.cpp" line="450"/>
+        <location filename="../plugin.cpp" line="460"/>
         <source>Move &quot;%1&quot;</source>
         <translation>Mover &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../plugin.cpp" line="458"/>
+        <location filename="../plugin.cpp" line="468"/>
         <source>Remove &quot;%1&quot;</source>
         <translation>Remover &quot;%1&quot;</translation>
     </message>
