@@ -1,10 +1,23 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ca">
+<context>
+    <name>ColorLabel</name>
+    <message>
+        <location filename="../colorLabel.cpp" line="36"/>
+        <source>Click to change color</source>
+        <translation>Cliqueu per canviar de color</translation>
+    </message>
+    <message>
+        <location filename="../colorLabel.cpp" line="65"/>
+        <source>Select Color</source>
+        <translation>Color de selecció</translation>
+    </message>
+</context>
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="188"/>
+        <location filename="../lxqtcustomcommand.cpp" line="197"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
@@ -22,12 +35,12 @@
         <translation>Mostra</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="191"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
         <source>Use icon from theme or browse file</source>
         <translation>Usa la icona del tema o navega fins al fitxer</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="84"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>Executa amb &quot;bash -c&quot;</translation>
     </message>
@@ -37,12 +50,12 @@
         <translation>Selecciona la lletra tipogràfica</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
         <source>Text</source>
         <translation>Text</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="72"/>
         <source>Command</source>
         <translation>Ordre</translation>
     </message>
@@ -52,27 +65,27 @@
         <translation>Lletra tipogràfica</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="221"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
         <source>Use %1 to display command output</source>
         <translation>Usa % 1 per mostrar la sortida de l&apos;ordre</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="201"/>
         <source>Icon</source>
         <translation>Icona</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>Browse</source>
         <translation>Navega</translation>
     </message>
@@ -82,70 +95,80 @@
         <translation>Gira automàticament quan el panell sigui vertical</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="74"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="94"/>
         <source>echo Configure...</source>
         <translation>Configuració de l&apos;eco...</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="77"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="288"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="305"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="322"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="308"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="342"/>
         <source>Command to run</source>
         <translation>Ordre a executar</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="258"/>
         <source>Max Width</source>
         <translation>Amplada màxima</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="156"/>
         <source>Repeat command after:</source>
         <translation>Repeteix l&apos;ordre després de:</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="152"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
+        <source>Text Color</source>
+        <translation>Color del text</translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="62"/>
+        <source>Reset</source>
+        <translation>Restableix</translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="172"/>
         <source> second(s)</source>
         <translation> segon(s)</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="174"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="194"/>
         <source>Command outputs an image</source>
         <translation>L&apos;ordre genera una imatge</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
         <source>Tooltip</source>
-        <translation type="unfinished"></translation>
+        <translation>Consell d&apos;eina</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="272"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
         <source>Mouse Commands</source>
         <translation>Ordres del ratolí</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="298"/>
         <source>Click</source>
         <translation>Clic</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="295"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="315"/>
         <source>Wheel Up</source>
         <translation>Roda amunt</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="312"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="332"/>
         <source>Wheel Down</source>
         <translation>Roda avall</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
         <source>Select Icon File</source>
         <translation>Trieu un fitxer d&apos;icona</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation>Imatges (*.png *.svg *.xpm *.jpg)</translation>
     </message>
