@@ -1,10 +1,23 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="en_GB">
+<context>
+    <name>ColorLabel</name>
+    <message>
+        <location filename="../colorLabel.cpp" line="36"/>
+        <source>Click to change color</source>
+        <translation>Click to change colour</translation>
+    </message>
+    <message>
+        <location filename="../colorLabel.cpp" line="65"/>
+        <source>Select Color</source>
+        <translation>Select Colour</translation>
+    </message>
+</context>
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="188"/>
+        <location filename="../lxqtcustomcommand.cpp" line="197"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
@@ -22,12 +35,12 @@
         <translation>Display</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="191"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
         <source>Use icon from theme or browse file</source>
         <translation>Use icon from theme or browse file</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="84"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>Run with &quot;bash -c&quot;</translation>
     </message>
@@ -37,12 +50,12 @@
         <translation>Select Font</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
         <source>Text</source>
         <translation>Text</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="72"/>
         <source>Command</source>
         <translation>Command</translation>
     </message>
@@ -52,100 +65,110 @@
         <translation>Font</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="221"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
         <source>Use %1 to display command output</source>
         <translation>Use %1 to display command output</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="201"/>
         <source>Icon</source>
         <translation>Icon</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>Browse</source>
-        <translation type="unfinished"></translation>
+        <translation>Browse</translation>
     </message>
     <message>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
         <source>Autorotate when the panel is vertical</source>
-        <translation type="unfinished"></translation>
+        <translation>Autorotate when the panel is vertical</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="74"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="94"/>
         <source>echo Configure...</source>
-        <translation type="unfinished"></translation>
+        <translation>echo Configure...</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="77"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="288"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="305"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="322"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="308"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="342"/>
         <source>Command to run</source>
-        <translation type="unfinished"></translation>
+        <translation>Command to run</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="258"/>
         <source>Max Width</source>
-        <translation type="unfinished"></translation>
+        <translation>Max Width</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="156"/>
         <source>Repeat command after:</source>
-        <translation type="unfinished"></translation>
+        <translation>Repeat command after:</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="152"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
+        <source>Text Color</source>
+        <translation>Text Colour</translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="62"/>
+        <source>Reset</source>
+        <translation>Reset</translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="172"/>
         <source> second(s)</source>
-        <translation type="unfinished"></translation>
+        <translation> second(s)</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="174"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="194"/>
         <source>Command outputs an image</source>
-        <translation type="unfinished"></translation>
+        <translation>Command outputs an image</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
         <source>Tooltip</source>
-        <translation type="unfinished"></translation>
+        <translation>Tooltip</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="272"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
         <source>Mouse Commands</source>
-        <translation type="unfinished"></translation>
+        <translation>Mouse Commands</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="298"/>
         <source>Click</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="295"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="315"/>
         <source>Wheel Up</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="312"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="332"/>
         <source>Wheel Down</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
         <source>Select Icon File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation type="unfinished"></translation>
     </message>
