@@ -1,10 +1,23 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_CN">
+<context>
+    <name>ColorLabel</name>
+    <message>
+        <location filename="../colorLabel.cpp" line="36"/>
+        <source>Click to change color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../colorLabel.cpp" line="65"/>
+        <source>Select Color</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="186"/>
+        <location filename="../lxqtcustomcommand.cpp" line="197"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
@@ -22,125 +35,140 @@
         <translation>显示</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
         <source>Use icon from theme or browse file</source>
         <translation>使用主题图标或浏览文件</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>使用“bash -c”运行</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
         <source>Select Font</source>
         <translation>选择字体</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
         <source>Text</source>
         <translation>文本</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="72"/>
         <source>Command</source>
         <translation>命令</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
         <source>Font</source>
         <translation>字体</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
         <source>Use %1 to display command output</source>
         <translation>使用 %1 显示命令输出</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="201"/>
         <source>Icon</source>
         <translation>图标</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>Browse</source>
         <translation>浏览</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
         <source>Autorotate when the panel is vertical</source>
         <translation>面板垂直时自动旋转</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="94"/>
         <source>echo Configure...</source>
         <translation>echo 配置...</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="308"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="342"/>
         <source>Command to run</source>
         <translation>运行命令</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="258"/>
         <source>Max Width</source>
         <translation>最大宽度</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="156"/>
         <source>Repeat command after:</source>
         <translation>在以下之后重复命令：</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
+        <source>Text Color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="62"/>
+        <source>Reset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="172"/>
         <source> second(s)</source>
         <translation> 秒（s）</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="194"/>
         <source>Command outputs an image</source>
         <translation>命令输出图像</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
+        <source>Tooltip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
         <source>Mouse Commands</source>
         <translation>鼠标命令</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="298"/>
         <source>Click</source>
         <translation>点击</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="315"/>
         <source>Wheel Up</source>
         <translation>滚轮向上</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="332"/>
         <source>Wheel Down</source>
         <translation>滚轮向下</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
         <source>Select Icon File</source>
         <translation>选择图标文件</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation>图片 (*.png *.svg *.xpm *.jpg)</translation>
     </message>
