@@ -4,14 +4,14 @@
 <context>
     <name>DesktopSwitch</name>
     <message>
-        <location filename="../desktopswitch.cpp" line="99"/>
+        <location filename="../desktopswitch.cpp" line="96"/>
         <source>Switch to desktop %1</source>
         <translatorcomment>Перейти на стільницю %1 </translatorcomment>
         <translation>Перемкнутися до стільниці %1</translation>
     </message>
     <message>
-        <location filename="../desktopswitch.cpp" line="160"/>
         <location filename="../desktopswitch.cpp" line="171"/>
+        <location filename="../desktopswitch.cpp" line="182"/>
         <source>Desktop %1</source>
         <translation>Стільниця %1</translation>
     </message>
@@ -20,7 +20,7 @@
     <name>DesktopSwitchConfiguration</name>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="14"/>
-        <source>DesktopSwitch settings</source>
+        <source>DesktopSwitch Settings</source>
         <translation>Налаштування перемикача стільниць</translation>
     </message>
     <message>
@@ -69,7 +69,7 @@
         <translation>Назви стільниць</translation>
     </message>
     <message>
-        <location filename="../desktopswitchconfiguration.cpp" line="71"/>
+        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
         <source>Desktop %1:</source>
         <translation>Стільниця %1:</translation>
     </message>
@@ -77,12 +77,12 @@
 <context>
     <name>DesktopSwitchUnsupported</name>
     <message>
-        <location filename="../desktopswitch.h" line="111"/>
+        <location filename="../desktopswitch.cpp" line="343"/>
         <source>n/a</source>
         <translation>н/д</translation>
     </message>
     <message>
-        <location filename="../desktopswitch.h" line="113"/>
+        <location filename="../desktopswitch.cpp" line="345"/>
         <source>DesktopSwitch is unsupported on current platform: %1</source>
         <translation>DesktopSwitch не підтримується на цій платформі: %1</translation>
     </message>
