@@ -1,23 +1,31 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ar">
+<context>
+    <name>DomPlugin</name>
+    <message>
+        <location filename="../domplugin.cpp" line="41"/>
+        <source>Panel DOM Tree</source>
+        <translation>لوحة شجرة DOM</translation>
+    </message>
+</context>
 <context>
     <name>TreeWindow</name>
     <message>
         <location filename="../treewindow.ui" line="14"/>
         <source>Panel DOM Tree</source>
-        <translation>شجرة DOM للوحة</translation>
+        <translation>لوحة شجرة DOM</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="63"/>
         <location filename="../treewindow.ui" line="96"/>
         <source>Property</source>
-        <translation>الصفة</translation>
+        <translation>ميزة</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="68"/>
         <source>Value</source>
-        <translation>القيمة</translation>
+        <translation>قيمة</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="76"/>
@@ -27,7 +35,7 @@
     <message>
         <location filename="../treewindow.ui" line="101"/>
         <source>Type</source>
-        <translation>النوع</translation>
+        <translation>نوع</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="106"/>
