@@ -1,12 +1,20 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="cy">
+<context>
+    <name>DomPlugin</name>
+    <message>
+        <location filename="../domplugin.cpp" line="41"/>
+        <source>Panel DOM Tree</source>
+        <translation type="unfinished">Panel DOM Tree</translation>
+    </message>
+</context>
 <context>
     <name>TreeWindow</name>
     <message>
         <location filename="../treewindow.ui" line="14"/>
         <source>Panel DOM Tree</source>
-        <translation></translation>
+        <translation>Panel DOM Tree</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="63"/>
