@@ -26,11 +26,7 @@
  * END_COMMON_COPYRIGHT_HEADER */
 
 #include "actionview.h"
-#ifdef HAVE_MENU_CACHE
-    #include "xdgcachedmenu.h"
-#else
-    #include <XdgAction>
-#endif
+#include <XdgAction>
 
 #include <QAction>
 #include <QWidgetAction>
@@ -45,10 +41,9 @@
 #include <QMimeData>
 #include <QUrl>
 
+#include <algorithm>
+
 //==============================
-#ifdef HAVE_MENU_CACHE
-#include <QSortFilterProxyModel>
-#else
 FilterProxyModel::FilterProxyModel(QObject* parent) :
     QSortFilterProxyModel(parent) {
 }
@@ -76,7 +71,6 @@ bool FilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex& sourc
     }
     return false;
 }
-#endif
 //==============================
 namespace
 {
@@ -110,15 +104,6 @@ namespace
         {
             QIcon icon = index.data(Qt::DecorationRole).value<QIcon>();
             //the XdgCachedMenuAction/XdgAction does load the icon upon showing its menu
-#ifdef HAVE_MENU_CACHE
-            if (icon.isNull())
-            {
-                XdgCachedMenuAction * cached_action = qobject_cast<XdgCachedMenuAction *>(qvariant_cast<QAction *>(index.data(ActionView::ActionRole)));
-                Q_ASSERT(nullptr != cached_action);
-                cached_action->updateIcon();
-                const_cast<QAbstractItemModel *>(index.model())->setData(index, cached_action->icon(), Qt::DecorationRole);
-            }
-#else
             if (icon.isNull())
             {
                 XdgAction * action = qobject_cast<XdgAction *>(qvariant_cast<QAction *>(index.data(ActionView::ActionRole)));
@@ -128,9 +113,8 @@ namespace
                   const_cast<QAbstractItemModel *>(index.model())->setData(index, action->icon(), Qt::DecorationRole);
                 }
             }
-#endif
             QSize s = QStyledItemDelegate::sizeHint(option, index);
-            s.setWidth(qMin(mMaxItemWidth, s.width()));
+            s.setWidth(std::min(mMaxItemWidth, s.width()));
             return s;
         }
     private:
@@ -142,11 +126,7 @@ namespace
 ActionView::ActionView(QWidget * parent /*= nullptr*/)
     : QListView(parent)
     , mModel{new QStandardItemModel{this}}
-#ifdef HAVE_MENU_CACHE
-    , mProxy{new QSortFilterProxyModel{this}}
-#else
     , mProxy{new FilterProxyModel{this}}
-#endif
     , mMaxItemsToShow(10)
 {
     setEditTriggers(QAbstractItemView::NoEditTriggers);
@@ -164,11 +144,11 @@ ActionView::ActionView(QWidget * parent /*= nullptr*/)
     mProxy->setFilterCaseSensitivity(Qt::CaseInsensitive);
     mProxy->sort(0);
     {
-        QScopedPointer<QItemSelectionModel> guard{selectionModel()};
+        std::unique_ptr<QItemSelectionModel> guard{selectionModel()};
         setModel(mProxy);
     }
     {
-        QScopedPointer<QAbstractItemDelegate> guard{itemDelegate()};
+        std::unique_ptr<QAbstractItemDelegate> guard{itemDelegate()};
         setItemDelegate(new DelayedIconDelegate{this});
     }
     connect(this, &QAbstractItemView::activated, this, &ActionView::onActivated);
@@ -227,11 +207,7 @@ void ActionView::fillActions(QMenu * menu)
 
 void ActionView::setFilter(QString const & filter)
 {
-#ifdef HAVE_MENU_CACHE
-    mProxy->setFilterFixedString(filter);
-#else
     mProxy->setfilerString(filter);
-#endif
     const int count = mProxy->rowCount();
     if (0 < count)
     {
@@ -271,7 +247,7 @@ QSize ActionView::viewportSizeHint() const
     {
         const bool scrollable = mMaxItemsToShow < count;
         s.setWidth(sizeHintForColumn(0) + (scrollable ? verticalScrollBar()->sizeHint().width() : 0));
-        s.setHeight(sizeHintForRow(0) * (scrollable ? mMaxItemsToShow  : count));
+        s.setHeight(sizeHintForRow(0) * (scrollable ? mMaxItemsToShow : count));
     }
     return s;
 }
@@ -284,7 +260,7 @@ QSize ActionView::minimumSizeHint() const
 void ActionView::mousePressEvent(QMouseEvent* event)
 {
     if (event->button() == Qt::LeftButton)
-        mDragStartPosition = event->pos();
+        mDragStartPosition = event->position().toPoint();
 
     QListView::mousePressEvent(event);
 }
@@ -294,7 +270,7 @@ void ActionView::mouseMoveEvent(QMouseEvent *event)
     if (!(event->buttons() & Qt::LeftButton))
         return;
 
-    if ((event->pos() - mDragStartPosition).manhattanLength() < QApplication::startDragDistance())
+    if ((event->position().toPoint() - mDragStartPosition).manhattanLength() < QApplication::startDragDistance())
         return;
 
     XdgAction *a = qobject_cast<XdgAction*>(indexAt(mDragStartPosition).data(ActionView::ActionRole).value<QAction*>());
