@@ -80,9 +80,12 @@ MenuDiskItem::MenuDiskItem(Solid::Device device, Popup *popup):
 
 MenuDiskItem::~MenuDiskItem() = default;
 
-void MenuDiskItem::setMountStatus(bool mounted)
+void MenuDiskItem::setMountStatus()
 {
-    mEjectButton->setEnabled(mounted);
+    if (mDevice.isValid())
+    {
+        mEjectButton->setEnabled(mDevice.as<Solid::StorageAccess>()->isAccessible() || !opticalParent().udi().isEmpty());
+    }
 }
 
 void MenuDiskItem::updateMountStatus()
@@ -96,7 +99,7 @@ void MenuDiskItem::updateMountStatus()
         mDiskButton->setIcon(icon);
         mDiskButton->setText(mDevice.description());
 
-        setMountStatus(mDevice.as<Solid::StorageAccess>()->isAccessible() || !opticalParent().udi().isEmpty());
+        setMountStatus();
     }
     else
         emit invalid(mDevice.udi());
