@@ -30,7 +30,7 @@
     </message>
     <message>
         <location filename="../qeyesconfigdialog.cpp" line="69"/>
-        <source>QEyes setting</source>
+        <source>QEyes Settings</source>
         <translation>إعداد كيو آيز</translation>
     </message>
     <message>
