@@ -33,11 +33,11 @@ Feature::Feature(const sensors_chip_name* sensorsChipName, const sensors_feature
     : mSensorsChipName(sensorsChipName),
       mSensorsFeature(sensorsFeature)
 {
-    char *featureLabel = NULL;
+    char *featureLabel = nullptr;
 
     if ((featureLabel = sensors_get_label(mSensorsChipName, mSensorsFeature)))
     {
-        mLabel = featureLabel;
+        mLabel = QString::fromUtf8(featureLabel);
         free(featureLabel);
     }
 
