@@ -9,48 +9,53 @@
         <translation>Настройки на системните известия</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="28"/>
-        <location filename="../statusnotifierconfiguration.ui" line="38"/>
+        <location filename="../statusnotifierconfiguration.ui" line="25"/>
+        <source>Reverse the order of items</source>
+        <translation>Обратно подреждане на елементите</translation>
+    </message>
+    <message>
+        <location filename="../statusnotifierconfiguration.ui" line="39"/>
+        <location filename="../statusnotifierconfiguration.ui" line="49"/>
         <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
         <translation>Елемент с автоматично скриване, ако изисква внимание, ще остане видим за този период от време.</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="31"/>
+        <location filename="../statusnotifierconfiguration.ui" line="42"/>
         <source>Attention period:</source>
         <translation>Период на активност:</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="41"/>
+        <location filename="../statusnotifierconfiguration.ui" line="52"/>
         <source> minute(s)</source>
         <translation> минути</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="72"/>
+        <location filename="../statusnotifierconfiguration.ui" line="83"/>
         <source>Change visibility of items</source>
         <translation>Промяна на видимост на елемент</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="85"/>
+        <location filename="../statusnotifierconfiguration.ui" line="96"/>
         <source>Item</source>
         <translation>Елемент</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="90"/>
+        <location filename="../statusnotifierconfiguration.ui" line="101"/>
         <source>Visibility</source>
         <translation>Видимост</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Always show</source>
         <translation>Винаги да се показва</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Auto-hide</source>
         <translation>Автоматично скриване</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Always hide</source>
         <translation>Винаги да се скрива</translation>
     </message>
