@@ -9,48 +9,53 @@
         <translation>Systeemvakinstellingen</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="28"/>
-        <location filename="../statusnotifierconfiguration.ui" line="38"/>
+        <location filename="../statusnotifierconfiguration.ui" line="25"/>
+        <source>Reverse the order of items</source>
+        <translation>Itemvolgorde omdraaien</translation>
+    </message>
+    <message>
+        <location filename="../statusnotifierconfiguration.ui" line="39"/>
+        <location filename="../statusnotifierconfiguration.ui" line="49"/>
         <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
         <translation>Een item dat automatisch wordt verborgen blijft zichtbaar voor deze duur als er een actie benodigd is.</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="31"/>
+        <location filename="../statusnotifierconfiguration.ui" line="42"/>
         <source>Attention period:</source>
         <translation>Actieperiode:</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="41"/>
+        <location filename="../statusnotifierconfiguration.ui" line="52"/>
         <source> minute(s)</source>
         <translation> minu(u)t(en)</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="72"/>
+        <location filename="../statusnotifierconfiguration.ui" line="83"/>
         <source>Change visibility of items</source>
         <translation>Zichtbaarheid van items aanpassen</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="85"/>
+        <location filename="../statusnotifierconfiguration.ui" line="96"/>
         <source>Item</source>
         <translation>Item</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="90"/>
+        <location filename="../statusnotifierconfiguration.ui" line="101"/>
         <source>Visibility</source>
         <translation>Zichtbaarheid</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Always show</source>
         <translation>Altijd tonen</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Auto-hide</source>
         <translation>Automatisch verbergen</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Always hide</source>
         <translation>Altijd verbergen</translation>
     </message>
