@@ -308,7 +308,7 @@ QMimeData * LXQtTaskButton::mimeData()
 {
     QMimeData *mimedata = new QMimeData;
     QByteArray ba;
-    QDataStream stream(&ba,QIODevice::WriteOnly);
+    QDataStream stream(&ba, QIODevice::WriteOnly);
     stream << (qlonglong)(mWindow);
     mimedata->setData(mimeDataFormat(), ba);
     return mimedata;
@@ -350,7 +350,7 @@ void LXQtTaskButton::mouseMoveEvent(QMouseEvent* event)
     if ((event->position().toPoint() - mDragStartPosition).manhattanLength() < QApplication::startDragDistance())
         return;
 
-    QDrag *drag = new QDrag(this);
+    QPointer<QDrag> drag = new QDrag(this);
     drag->setMimeData(mimeData());
     QIcon ico = icon();
     QPixmap img = ico.pixmap(ico.actualSize({32, 32}));
@@ -372,12 +372,13 @@ void LXQtTaskButton::mouseMoveEvent(QMouseEvent* event)
 
     // if button is dropped out of panel (e.g. on desktop)
     // it is not deleted automatically by Qt
-    drag->deleteLater();
+    if (drag)
+        drag->deleteLater();
 
     // release mouse appropriately, by positioning the event outside
     // the button rectangle (otherwise, the button will be toggled)
     QMouseEvent releasingEvent(QEvent::MouseButtonRelease,
-                               QPoint(-1,-1), mapToGlobal(QPoint(-1, -1)),
+                               QPoint(-1, -1), mapToGlobal(QPoint(-1, -1)),
                                Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
     mouseReleaseEvent(&releasingEvent);
 
