@@ -36,6 +36,8 @@
 
 #include <QBitmap>
 
+#include <algorithm>
+
 #include <KWindowSystem>
 #include <netwm.h>
 
@@ -144,19 +146,19 @@ SNIProxy::SNIProxy(xcb_window_t wid, Xcb::Atoms & atoms, QObject *parent)
     values[2] = XCB_EVENT_MASK_VISIBILITY_CHANGE | // receive visibility change, to handle KWin restart #357443
                                                    // Redirect and handle structure (size, position) requests from the embedded window.
         XCB_EVENT_MASK_STRUCTURE_NOTIFY | XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY | XCB_EVENT_MASK_SUBSTRUCTURE_REDIRECT;
-    xcb_create_window(m_connection, /* connection    */
-                      XCB_COPY_FROM_PARENT, /* depth         */
-                      m_containerWid, /* window Id     */
+    xcb_create_window(m_connection, /* connection */
+                      XCB_COPY_FROM_PARENT, /* depth */
+                      m_containerWid, /* window Id */
                       screen->root, /* parent window */
                       0,
-                      0, /* x, y          */
+                      0, /* x, y */
                       s_embedSize,
                       s_embedSize, /* width, height */
-                      0, /* border_width  */
-                      XCB_WINDOW_CLASS_INPUT_OUTPUT, /* class         */
-                      screen->root_visual, /* visual        */
+                      0, /* border_width */
+                      XCB_WINDOW_CLASS_INPUT_OUTPUT, /* class */
+                      screen->root_visual, /* visual */
                       mask,
-                      values); /* masks         */
+                      values); /* masks */
 
     /*
         We need the window to exist and be mapped otherwise the child won't render it's contents
@@ -484,7 +486,7 @@ KDbusImageVector SNIProxy::IconPixmap() const
     // add pixmaps up to s_embedSize resolution (for the SNI presenter to be able to choose, if needed)
     for (int s = 16; s <= s_embedSize && !m_iconImage.isNull(); s <<= 1)
     {
-        if (qMax(m_iconImage.size().width(), m_iconImage.size().height()) < s)
+        if (std::max(m_iconImage.size().width(), m_iconImage.size().height()) < s)
         {
             v << m_iconImage.scaled(s, s, Qt::KeepAspectRatio, Qt::SmoothTransformation);
         }
